@@ -8,7 +8,7 @@ Python: 3.7.7
 """
 
 
-from SystemIDAlgorithms.QMarkovCover import qMarkovCover
+from systemID.SystemIDAlgorithms.QMarkovCover import qMarkovCover
 
 
 class ERA:
