@@ -10,7 +10,7 @@ Python: 3.7.7
 
 import numpy as np
 
-from SystemIDAlgorithms.EigenSystemRealizationAlgorithmFromInitialConditionResponse import eigenSystemRealizationAlgorithmFromInitialConditionResponse
+from systemID.SystemIDAlgorithms.EigenSystemRealizationAlgorithmFromInitialConditionResponse import eigenSystemRealizationAlgorithmFromInitialConditionResponse
 
 def dynamicModeDecompositionAlgorithm(output_signals, state_dimension, input_dimension):
 
