@@ -9,7 +9,7 @@ Python: 3.7.7
 
 
 import numpy as np
-from SystemIDAlgorithms.GetTimeVaryingMarkovParameters import getTimeVaryingMarkovParameters
+from systemID.SystemIDAlgorithms.GetTimeVaryingMarkovParameters import getTimeVaryingMarkovParameters
 
 
 def getDeltaMatrix(A, B, C, D, tk, dt, number_steps):
