@@ -11,7 +11,7 @@ Python: 3.7.7
 import numpy as np
 import scipy.linalg as LA
 
-from SystemIDAlgorithms.GetObservabilityMatrix import getObservabilityMatrix
+from systemID.SystemIDAlgorithms.GetObservabilityMatrix import getObservabilityMatrix
 
 
 def getTimeVaryingObserverGainMatrix(A, C, hkio, order, dt):
