@@ -11,7 +11,7 @@ Python: 3.7.7
 import numpy as np
 from scipy.integrate import odeint
 
-from SystemIDAlgorithms.Integrate import integrate
+from systemID.SystemIDAlgorithms.Integrate import integrate
 
 
 def propagation(signal, system, **kwargs):
