@@ -10,7 +10,7 @@ Python: 3.7.7
 
 import numpy as np
 
-from ClassesGeneral.ClassSignal import DiscreteSignal
+from systemID.ClassesGeneral.ClassSignal import DiscreteSignal
 
 
 def weightingSequenceDescription(input_signal, markov_parameters, **kwargs):
